@@ -17,6 +17,7 @@ from knack.util import CLIError
 from azdev.utilities import (
     cmd, py_cmd, pip_cmd, display, get_ext_repo_paths, find_files, get_azure_config, get_azdev_config,
     require_azure_cli, heading, subheading, EXTENSION_PREFIX)
+from .version_upgrade import VersionUpgradeMod
 
 logger = get_logger(__name__)
 
@@ -137,6 +138,36 @@ def list_extensions():
     return results
 
 
+def show_extension(mod_name):
+    ext_paths = get_ext_repo_paths()
+    ext_mod_paths = [os.path.join(ext, "src", mod_name) for ext in ext_paths]
+    mod_install_path = find_files(ext_mod_paths, '*.*-info')
+
+    if not mod_install_path:
+        raise CLIError('extension not installed using azdev: {}'.format(mod_name))
+
+    if len(mod_install_path) > 1:
+        raise CLIError('extension {} duplicated, please specify extension name'.format(mod_name))
+
+    mod_install_dir = os.path.dirname(mod_install_path[0])
+    long_name = os.path.basename(mod_install_dir)
+    assert long_name == mod_name
+    mod_info = {
+        "name": mod_name,
+        "path": mod_install_dir
+    }
+    # extract pkg name from egg-info or dist-info folders
+    logger.debug("Extracting pkg info from %s...", mod_install_path[0])
+    meta_files = ["PKG-INFO", "METADATA"]
+    pkg_info_path = [os.path.join(mod_install_path[0], meta) for meta in meta_files
+                     if os.path.isfile(os.path.join(mod_install_path[0], meta))]
+    from .util import get_pkg_info_from_pkg_metafile
+    for pkg_info_file in pkg_info_path:
+        pkg_info = get_pkg_info_from_pkg_metafile(pkg_info_file)
+        mod_info.update(pkg_info)
+    return mod_info
+
+
 def _get_sha256sum(a_file):
     import hashlib
     sha256 = hashlib.sha256()
@@ -328,3 +359,14 @@ def publish_extensions(extensions, storage_account, storage_account_key, storage
     if not update_index:
         logger.warning('You still need to update the index for your changes!')
         logger.warning('    az extension update-index <URL>')
+
+
+def cal_next_version(base_meta_file, diff_meta_file, current_version, is_preview=None, is_experimental=None,
+                     next_version_pre_tag=None, next_version_segment_tag=None):
+    with open(base_meta_file, "r") as g:
+        command_tree = json.load(g)
+        module_name = command_tree["module_name"]
+    version_op = VersionUpgradeMod(module_name, current_version, is_preview, is_experimental,
+                                   base_meta_file, diff_meta_file, next_version_pre_tag, next_version_segment_tag)
+    version_op.update_next_version()
+    return version_op.format_outputs()
